@@ -14,7 +14,7 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202202'
+__version__ = '2.202203'
 __dhlib__ = '/usr/share/debhelper/dh_make'
 policy_version = '4.6.1'
 
@@ -769,7 +769,7 @@ def do_debianize(args, subs):
 #\t-DCMAKE_LIBRARY_PATH=$(DEB_HOST_MULTIARCH)'''
         if os.path.isfile('./configure') and os.access('./configure', os.X_OK):
             setup_autotools(subs)
-        elif os.path.isfile('CmakeLists.txt'):
+        elif os.path.isfile('CMakeLists.txt'):
             setup_cmake(subs)
         else:
             setup_make()
